pub struct CurrencyCode { /* private fields */ }Expand description
It’s recommended to use the constants in the currencies module.
Implementations
Sourceimpl CurrencyCode
impl CurrencyCode
Sourcepub unsafe fn new_unchecked(code: &[u8]) -> Self
pub unsafe fn new_unchecked(code: &[u8]) -> Self
Creates a new CurrencyCode value.
Safety
Ensure that the code’s length is within range [2..5]. The code must consist only of uppercase ASCII characters, and be terminated by zeroes until the end of the slice.